bl_info = {
    "name": "Object Counter",
    "blender": (2, 82, 0),  # Минимальная версия Blender
    "category": "Object",
    "description": "Counts objects in the scene based on name filtering",
    "author": "Yuriy Gusev",
    "version": (1, 0),
    "support": "COMMUNITY",
}

import bpy

class ObjectCounterPanel(bpy.types.Panel):
    bl_label = "Object Counter"
    bl_idname = "OBJECT_COUNTER_PT_panel"
    bl_space_type = 'PROPERTIES'
    bl_region_type = 'WINDOW'
    bl_context = "scene"

    def draw(self, context):
        layout = self.layout
        scene = context.scene
        
        layout.prop(scene, "object_counter_name")

        row = layout.row()
        row.operator("object.count_objects", text="Count Objects")
        
        if scene.object_counter_result is not None:
            layout.label(text=f"Total Objects: {scene.object_counter_result}")

class CountObjectsOperator(bpy.types.Operator):
    bl_idname = "object.count_objects"
    bl_label = "Count Objects"

    def execute(self, context):
        scene = context.scene
        name_filter = scene.object_counter_name.lower()
        
        # Счетчик объектов
        total_count = 0
        
        for obj in bpy.data.objects:
            # Учитываем объекты с учетом фильтра
            if name_filter in obj.name.lower():
                total_count += 1

                # Проверяем модификатор Array
                if obj.modifiers:
                    for modifier in obj.modifiers:
                        if modifier.type == 'ARRAY':
                            total_count += modifier.count - 1  # минус 1, так как один объект уже учитывается

        scene.object_counter_result = total_count
        return {'FINISHED'}

def register():
    bpy.utils.register_class(ObjectCounterPanel)
    bpy.utils.register_class(CountObjectsOperator)
    bpy.types.Scene.object_counter_name = bpy.props.StringProperty(name="Object Name")
    bpy.types.Scene.object_counter_result = bpy.props.IntProperty(name="Object Count", default=0)

def unregister():
    bpy.utils.unregister_class(ObjectCounterPanel)
    bpy.utils.unregister_class(CountObjectsOperator)
    del bpy.types.Scene.object_counter_name
    del bpy.types.Scene.object_counter_result

if __name__ == "__main__":
    register()
